<?php
/**
 * Plugin Name: AI Bulk Post Generator
 * Plugin URI: https://wpdeveloper.holeiholo.com
 * Description: Automatically generates and publishes bulk posts with AI-generated content, keywords, meta details, and images.
 * Version: 1.1
 * Author: Hasibul Hasan Rajib
 * Author URI: https://hasibulhasan.holeiholo.com
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: ai-bulk-post-generator
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Prevent duplicate function declaration
if (!function_exists('ai_bulk_post_generator_menu')) {
    function ai_bulk_post_generator_menu() {
        add_menu_page(
            'AI Bulk Post Generator',
            'AI Bulk Posts',
            'manage_options',
            'ai-bulk-post-generator',
            'ai_bulk_post_generator_page',
            'dashicons-admin-generic',
            20
        );
    }
    add_action('admin_menu', 'ai_bulk_post_generator_menu');
}

// Plugin settings page
function ai_bulk_post_generator_page() {
    ?>
    <div class="wrap my-plugin-wrapper">
        <h1>AI Bulk Post Generator</h1>
        <form method="post" action="">
            <?php wp_nonce_field('ai_bulk_generate_nonce', 'ai_bulk_nonce'); ?>
            
            <label for="post_count">Number of Posts:</label>
            <input type="number" name="post_count" id="post_count" value="10" min="1" max="100" required>
            <br><br>

            <label for="keywords">Enter Keywords (comma separated):</label>
            <textarea name="keywords" id="keywords" rows="3" required></textarea>
            <br><br>

            <label for="category">Select Category:</label>
            <select name="category" id="category">
                <?php
                $categories = get_categories();
                foreach ($categories as $category) {
                    echo '<option value="' . esc_attr($category->term_id) . '">' . esc_html($category->name) . '</option>';
                }
                ?>
            </select>
            <br><br>
            
            <input type="submit" name="generate_posts" value="Generate Posts" class="button button-primary">
        </form>
    </div>
    <?php

    if (isset($_POST['generate_posts'])) {
        if (!isset($_POST['ai_bulk_nonce']) || !wp_verify_nonce($_POST['ai_bulk_nonce'], 'ai_bulk_generate_nonce')) {
            wp_die('Security check failed.');
        }

        $post_count = intval($_POST['post_count']);
        $keywords = sanitize_textarea_field($_POST['keywords']);
        $category_id = intval($_POST['category']);

        ai_bulk_generate_posts($post_count, $keywords, $category_id);
    }
}

// Generate AI Content with at least 2400 characters
function ai_generate_content($title, $keyword) {
    $content = "<h2>Introduction</h2>";
    $content .= "<p>$keyword is an essential topic in today's digital landscape. In this article, we will explore its importance, key aspects, and practical applications.</p>";

    $content .= "<h2>Why is $keyword Important?</h2>";
    $content .= "<p>Understanding $keyword is crucial because it plays a significant role in various industries. Whether you are a beginner or an expert, mastering this subject can help you in many ways.</p>";

    $content .= "<h2>Key Benefits of $keyword</h2>";
    $content .= "<ul>
                    <li><strong>Improves Productivity:</strong> Learning about $keyword helps you streamline your workflow.</li>
                    <li><strong>Enhances Skills:</strong> Gaining knowledge in $keyword allows for better career opportunities.</li>
                    <li><strong>Boosts Creativity:</strong> Exploring different aspects of $keyword fosters innovation.</li>
                </ul>";

    $content .= "<h2>How to Get Started with $keyword</h2>";
    $content .= "<p>To start with $keyword, follow these steps:</p>";
    $content .= "<ol>
                    <li>Understand the fundamentals and key concepts.</li>
                    <li>Practice using real-world examples and case studies.</li>
                    <li>Join online communities and discussion forums for further learning.</li>
                </ol>";

    $content .= "<h2>Conclusion</h2>";
    $content .= "<p>By learning about $keyword, you can unlock new opportunities and improve your expertise. Keep exploring and applying your knowledge to gain the best results.</p>";

    // Ensure the content is at least 2400 characters
    while (strlen($content) < 2400) {
        $content .= "<p>Further insights and case studies can deepen your understanding of $keyword.</p>";
    }

    return $content;
}

// Generate AI Meta Title
function ai_generate_meta_title($keyword) {
    return ucfirst($keyword) . " - Ultimate Guide & Insights";
}

// Generate AI Meta Description
function ai_generate_meta_description($keyword) {
    return "Discover detailed insights about " . ucfirst($keyword) . ". Read expert articles covering important aspects and latest updates.";
}

// AI Image Generator (Fetch from Free Sources)
function ai_fetch_image($keyword) {
    return esc_url("https://source.unsplash.com/800x600/?" . urlencode($keyword));
}

// Generate Bulk Posts
function ai_bulk_generate_posts($post_count, $keywords, $category_id) {
    $keywords_array = explode(',', $keywords);
    $keyword_count = count($keywords_array);

    for ($i = 0; $i < $post_count; $i++) {
        $random_keyword = trim($keywords_array[rand(0, $keyword_count - 1)]);
        $title = sanitize_text_field(ucfirst($random_keyword));
        $content = ai_generate_content($title, $random_keyword);
        $meta_title = ai_generate_meta_title($random_keyword);
        $meta_description = ai_generate_meta_description($random_keyword);
        $image_url = ai_fetch_image($random_keyword);

        $post_data = array(
            'post_title'    => wp_strip_all_tags($title),
            'post_content'  => "<img src='$image_url' alt='" . esc_attr($random_keyword) . "'><p>$content</p>",
            'post_status'   => 'publish',
            'post_category' => array($category_id),
            'post_type'     => 'post',
            'meta_input'    => array(
                'meta_title'       => $meta_title,
                'meta_description' => $meta_description
            )
        );

        wp_insert_post($post_data);
    }

    echo '<div class="updated"><p><strong>' . esc_html($post_count) . ' posts created successfully!</strong></p></div>';
}

// Enqueue Plugin CSS (Admin Panel)
function ai_plugin_enqueue_admin_styles($hook) {
    if ($hook !== 'toplevel_page_ai-bulk-post-generator') {
        return;
    }
    wp_enqueue_style('ai-plugin-admin-css', plugin_dir_url(__FILE__) . 'style.css');
}
add_action('admin_enqueue_scripts', 'ai_plugin_enqueue_admin_styles');

// Enqueue Bootstrap in Admin Panel
function ai_plugin_enqueue_admin_bootstrap($hook) {
    if ($hook !== 'toplevel_page_ai-bulk-post-generator') {
        return;
    }
    wp_enqueue_style('bootstrap-css', 'https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css');
    wp_enqueue_script('bootstrap-js', 'https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js', array('jquery'), null, true);
}
add_action('admin_enqueue_scripts', 'ai_plugin_enqueue_admin_bootstrap');
?>
